@@ -1,43 +1,47 @@
 # -*- coding: utf-8 -*-
-import re
-import os
+from __future__ import unicode_literals
+
+import sphinx_py3doc_enhanced_theme
+
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.autosummary',
-    'sphinx.ext.todo',
     'sphinx.ext.coverage',
+    'sphinx.ext.doctest',
+    'sphinx.ext.extlinks',
     'sphinx.ext.ifconfig',
+    'sphinx.ext.napoleon',
+    'sphinx.ext.todo',
     'sphinx.ext.viewcode',
-    'sphinxcontrib.napoleon'
 ]
-if os.getenv('SPELLCHECK'):
-    extensions += 'sphinxcontrib.spelling',
-    spelling_show_suggestions = True
-    spelling_lang = 'en_US'
-
 source_suffix = '.rst'
 master_doc = 'index'
-project = u'aspectlib'
-copyright = u'2014, Ionel Cristian Mărieș'
-version = release = re.findall(
-    'version="(.*)"',
-    open(os.path.join(os.path.dirname(__file__), '../setup.py')).read()
-)[0]
-
-import sphinx_py3doc_enhanced_theme
-html_theme = "sphinx_py3doc_enhanced_theme"
-html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
+project = 'Aspectlib'
+year = '2014-2020'
+author = 'Ionel Cristian Mărieș'
+copyright = '{0}, {1}'.format(year, author)
+version = release = '1.5.0'
 
 pygments_style = 'trac'
 templates_path = ['.']
+extlinks = {
+    'issue': ('https://github.com/ionelmc/python-aspectlib/issues/%s', '#'),
+    'pr': ('https://github.com/ionelmc/python-aspectlib/pull/%s', 'PR #'),
+}
+html_theme = "sphinx_py3doc_enhanced_theme"
+html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
+html_theme_options = {
+    'githuburl': 'https://github.com/ionelmc/python-aspectlib/'
+}
+
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
-exclude_trees = ['pydoctheme']
-html_split_index = True
+html_split_index = False
 html_sidebars = {
    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
 html_short_title = '%s-%s' % (project, version)
-html_theme_options = {
-    'githuburl': 'https://github.com/ionelmc/python-aspectlib/'
-}
+
+napoleon_use_ivar = True
+napoleon_use_rtype = False
+napoleon_use_param = False
